==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/videoanalyzer/kotlin/inputs/VideoAnalyzerIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.videoanalyzer.kotlin.inputs

import com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The managed identity for the Video Analyzer resource.
 * @property type The identity type.
 * @property userAssignedIdentities The User Assigned Managed Identities.
 */
public data class VideoAnalyzerIdentityArgs(
    public val type: Output<String>,
    public val userAssignedIdentities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs> {
    override fun toJava(): com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs =
        com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs.builder()
            .type(type.applyValue({ args0 -> args0 }))
            .userAssignedIdentities(
                userAssignedIdentities?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [VideoAnalyzerIdentityArgs].
 */
@PulumiTagMarker
public class VideoAnalyzerIdentityArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    private var userAssignedIdentities: Output<List<String>>? = null

    /**
     * @param value The identity type.
     */
    @JvmName("mfpwfktrdsybhaxg")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The User Assigned Managed Identities.
     */
    @JvmName("tyegjxemtmcyrhia")
    public suspend fun userAssignedIdentities(`value`: Output<List<String>>) {
        this.userAssignedIdentities = value
    }

    @JvmName("uxbcclkpvrineyuy")
    public suspend fun userAssignedIdentities(vararg values: Output<String>) {
        this.userAssignedIdentities = Output.all(values.asList())
    }

    /**
     * @param values The User Assigned Managed Identities.
     */
    @JvmName("rpmmgbupqcskbwrx")
    public suspend fun userAssignedIdentities(values: List<Output<String>>) {
        this.userAssignedIdentities = Output.all(values)
    }

    /**
     * @param value The identity type.
     */
    @JvmName("urtsnramfdqbysuq")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The User Assigned Managed Identities.
     */
    @JvmName("gnuajpbdhnytfsii")
    public suspend fun userAssignedIdentities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    /**
     * @param values The User Assigned Managed Identities.
     */
    @JvmName("kyiydnxkwvvxyjvt")
    public suspend fun userAssignedIdentities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    internal fun build(): VideoAnalyzerIdentityArgs = VideoAnalyzerIdentityArgs(
        type = type ?: throw PulumiNullFieldException("type"),
        userAssignedIdentities = userAssignedIdentities,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/videoanalyzer/kotlin/inputs/VideoAnalyzerIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.videoanalyzer.kotlin.inputs

import com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The managed identity for the Video Analyzer resource.
 * @property type The identity type.
 * @property userAssignedIdentities The User Assigned Managed Identities.
 */
public data class VideoAnalyzerIdentityArgs(
    public val type: Output<String>,
    public val userAssignedIdentities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs> {
    override fun toJava(): com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs =
        com.pulumi.azurenative.videoanalyzer.inputs.VideoAnalyzerIdentityArgs.builder()
            .type(type.applyValue({ args0 -> args0 }))
            .userAssignedIdentities(
                userAssignedIdentities?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [VideoAnalyzerIdentityArgs].
 */
@PulumiTagMarker
public class VideoAnalyzerIdentityArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    private var userAssignedIdentities: Output<List<String>>? = null

    /**
     * @param value The identity type.
     */
    @JvmName("vwtoswmdwgxnpxsb")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The User Assigned Managed Identities.
     */
    @JvmName("ovnrmvfkmsldesqw")
    public suspend fun userAssignedIdentities(`value`: Output<List<String>>) {
        this.userAssignedIdentities = value
    }

    @JvmName("fcitmdurkvvrpsdd")
    public suspend fun userAssignedIdentities(vararg values: Output<String>) {
        this.userAssignedIdentities = Output.all(values.asList())
    }

    /**
     * @param values The User Assigned Managed Identities.
     */
    @JvmName("bggktbiderdbdyed")
    public suspend fun userAssignedIdentities(values: List<Output<String>>) {
        this.userAssignedIdentities = Output.all(values)
    }

    /**
     * @param value The identity type.
     */
    @JvmName("agbumvfusyxehrds")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The User Assigned Managed Identities.
     */
    @JvmName("oitefoxdkmatrwwk")
    public suspend fun userAssignedIdentities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    /**
     * @param values The User Assigned Managed Identities.
     */
    @JvmName("khbsdngdpmnefcam")
    public suspend fun userAssignedIdentities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    internal fun build(): VideoAnalyzerIdentityArgs = VideoAnalyzerIdentityArgs(
        type = type ?: throw PulumiNullFieldException("type"),
        userAssignedIdentities = userAssignedIdentities,
    )
}
